@@ -207,23 +207,45 @@ namespace sync {
 /// Output is fully thread-safe (the outputs are "atomic" to the file or
 /// stream), and if the stream is buffered, it is flushed after the output).
 
-template<typename... Args>
-inline void print (FILE *file, const char* fmt, const Args&... args)
+#if FMT_VERSION >= 70000
+template<typename Str, typename... Args>
+inline void print (FILE *file, const Str& fmt, Args&&... args)
 {
-    sync_output (file, ::fmt::format(fmt, args...));
+    sync_output (file, ::fmt::vformat(fmt, ::fmt::make_format_args(args...)));
+}
+
+template<typename Str, typename... Args>
+inline void print (const Str& fmt, Args&&... args)
+{
+    sync_output(stdout, ::fmt::vformat(fmt, ::fmt::make_format_args(args...)));
+}
+
+template<typename Str, typename... Args>
+inline void print (std::ostream &file, const Str& fmt, Args&&... args)
+{
+    sync_output (file, ::fmt::vformat(fmt, ::fmt::make_format_args(args...)));
+}
+
+#else
+
+template<typename... Args>
+inline void print (FILE *file, const char* fmt, Args&&... args)
+{
+    sync_output (file, ::fmt::format(fmt, std::forward<Args>(args)...));
 }
 
 template<typename... Args>
-inline void print (const char* fmt, const Args&... args)
+inline void print (const char* fmt, Args&&... args)
 {
-    print(stdout, fmt, args...);
+    print(stdout, fmt, std::forward<Args>(args)...);
 }
 
 template<typename... Args>
-inline void print (std::ostream &file, const char* fmt, const Args&... args)
+inline void print (std::ostream &file, const char* fmt, Args&&... args)
 {
-    sync_output (file, ::fmt::format(fmt, args...));
+    sync_output (file, ::fmt::format(fmt, std::forward<Args>(args)...));
 }
+#endif
 } // namespace sync
 
 
@@ -558,9 +580,7 @@ std::string join (const Sequence& seq, string_view sep /*= ""*/, size_t len)
 }
 
 /// Concatenate two strings, returning a std::string, implemented carefully
-/// to not perform any redundant copies or allocations. This is
-/// semantically equivalent to `Strutil::sprintf("%s%s", s, t)`, but is
-/// more efficient.
+/// to not perform any redundant copies or allocations.
 std::string OIIO_UTIL_API concat(string_view s, string_view t);
 
 /// Repeat a string formed by concatenating str n times.
@@ -918,6 +938,14 @@ inline void trim_whitespace (string_view &str) noexcept {
     remove_trailing_whitespace(str);
 }
 
+/// Return the portion of str that is trimmed of any whitespace (space, tab,
+/// linefeed, cr) from both the front and back.
+inline string_view trimmed_whitespace (string_view str) noexcept {
+    skip_whitespace(str);
+    remove_trailing_whitespace(str);
+    return str;
+}
+
 /// If str's first character is c (or first non-whitespace char is c, if
 /// skip_whitespace is true), return true and additionally modify str to
 /// skip over that first character if eat is also true. Otherwise, if str
@@ -1113,4 +1141,8 @@ edit_distance(string_view a, string_view b,
 
 }  // namespace Strutil
 
+
+// Bring the ever-useful Strutil::print into the OIIO namespace.
+using Strutil::print;
+
 OIIO_NAMESPACE_END
